@@ -104,9 +104,8 @@ async def fill_template(email_list: list[str]) -> list[str]:
     return template_list
 
 @mcp.tool()
-async def continue_email_generation(res: FileResource, row_number: int):
+async def continue_email_generation(file_path: str, row_number: int):
     row_number += 1
-    file_path = os.path.join(os.path.dirname(__file__), res.path)
     result = await generate_email(file_path, row_number)
     return result
 
@@ -116,7 +115,8 @@ async def start_email_generation(res: FileResource):
     result = await generate_email(file_path, 0)
     return result
 
-async def generate_email(file_path: str, row_number: int) -> str:
+@mcp.tool()
+async def generate_email(file_path: str, row_number: int):
     email = "Email"
     try:
         with open(file_path, mode="r", encoding="latin-1") as file:
@@ -133,8 +133,7 @@ async def generate_email(file_path: str, row_number: int) -> str:
                         print(f"Row {row_number}: Skipping - insufficient data")
                         continue
 
-                    return "FUCK YOU"
-                    result = await asyncio.wait_for(gtm_agent.generate_mail(row, row_number))
+                    result = await (gtm_agent.generate_mail(row, row_number))
 
                     email = f"Generated email:\n{result}"
                     print(email)
@@ -148,8 +147,7 @@ async def generate_email(file_path: str, row_number: int) -> str:
 
             print(f"Processing complete: {processed} emails processed, {errors} errors")
 
-
-            return email
+        return email
 
     except Exception as e:
         print(f"Error in process_emails: {e}")
